#
# spec file for package pssh
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_version 2.3.4
%define python_version 3
%if ! %{defined python3_sitelib}
%define python3_sitelib /usr/lib/python3.6/site-packages/
%endif

Name:           pssh
Version:        2.3.4+git10.d4909c9
Release:        4.3
Summary:        Parallel SSH to control large numbers of Machines simultaneously
License:        BSD-3-Clause
Group:          Productivity/Clustering/Computing
URL:            https://github.com/lilydjwg/pssh
Source:         pssh-%{version}.tar.xz
# PATCH-FIX-OPENSUSE 0001-Remove-shebangs-from-library-files.patch dejan@suse.de -- remove
# shebangs from library files
Patch1:         0001-Remove-shebangs-from-library-files.patch
# PATCH-FEATURE-UPSTREAM 0002-Add-quiet-option.patch dejan@suse.de -- add
# the -q (quiet) option
Patch2:         0002-Add-quiet-option.patch
# PATCH-FIX-UPSTREAM 0003-Fix-order-of-command-statuses-returned-by-the-Manage.patch bnc#828897 dejan@suse.de -- Fix
# order of command statuses returned by the Manager
Patch3:         0003-Fix-order-of-command-statuses-returned-by-the-Manage.patch
# PATCH-FIX-OPENSUSE 0007-openSUSE-Add-openSUSE-specific-pssh-askpass-location.patch dejan@suse.de -- add
# openSUSE specific pssh-askpass location
Patch7:         0007-openSUSE-Add-openSUSE-specific-pssh-askpass-location.patch
# PATCH-FEATURE-UPSTREAM 0008-openSUSE-add-C-pcmk_nodes-option-to-get-list-of-node.patch dejan@suse.de -- add
# -C/--pcmk_nodes option to get list of nodes from Pacemaker
Patch8:         0008-openSUSE-add-C-pcmk_nodes-option-to-get-list-of-node.patch
# PATCH-FEATURE-UPSTREAM Prepend hostname on each line when -P is set
Patch9:         0001-Prepend-hostname-on-each-line-when-P-is-set.patch
BuildRequires:  python%{python_version}-devel
BuildRequires:  python%{python_version}-setuptools
BuildRequires:  python-rpm-macros
Requires:       python-pssh = %{version}-%{release}
BuildArch:      noarch

%description
pssh provides parallel versions of the OpenSSH tools that are useful for
controlling large numbers of machines simultaneously. It includes parallel
versions of ssh, scp, and rsync, as well as a parallel kill command.

%package -n python-pssh
Summary:        Python Module for Parallel SSH
Group:          Development/Libraries/Python
Requires:       openssh
Requires:       rsync

%description -n python-pssh
pssh provides parallel versions of the OpenSSH tools that are useful for
controlling large numbers of machines simultaneously. It includes parallel
versions of ssh, scp, and rsync, as well as a parallel kill command.

This package contains the pssh Python module.

%prep
%autosetup -p1

%build
python%{python_version} setup.py build

%install
python%{python_version} setup.py install \
	 --prefix="%{_prefix}" \
	 --root=%{buildroot}

%files
%doc AUTHORS ChangeLog
%license COPYING
%if 0%{?centos_version} || 0%{?centos} || 0%{?rhel_version} || 0%{?rhel}
%{!?ext_man: %define ext_man .gz}
%endif
%{_mandir}/man1/pssh.1%{?ext_man}
%{_mandir}/man1/pnuke.1%{?ext_man}
%{_mandir}/man1/pscp.1%{?ext_man}
%{_mandir}/man1/pslurp.1%{?ext_man}
%{_mandir}/man1/prsync.1%{?ext_man}
%{_bindir}/pnuke
%{_bindir}/prsync
%{_bindir}/pscp
%{_bindir}/pslurp
%{_bindir}/pssh
%{_bindir}/pssh-askpass

%files -n python-pssh
%license COPYING
%doc AUTHORS ChangeLog
%{python3_sitelib}/%{name}-%{pkg_version}*
%{python3_sitelib}/%{name}lib

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Mar 23 2022 Yan Gao <ygao@suse.com>
- spec: use python3_sitelib macro rather than python_sitelib
- bin: fix inconsistent use of tabs and spaces in indentation
- psshlib: fix invalid syntax of except
- Update:
  * 0008-openSUSE-add-C-pcmk_nodes-option-to-get-list-of-node.patch
* Mon Aug 23 2021 Peter Varkoly <varkoly@suse.com>
- Fix spec to be able to build on openLeap 15.N
* Sat Aug 21 2021 varkoly@suse.com
- Update to version 2.3.4+git10.d4909c9:
  * add install instruction
  * fix manpages
  * prsync: support downloading
  * bin/*: explicitly run with python3
  * binary files do not support line buffering, fix #118
  * add flag for file append
  * change default file write behaviour to append over recreate
  * remove ancient workaround to workaround a new bug
  * Bump version to 2.3.4
  * support only Python 3.5+
- Use %%license for current distribution versions.
- Remove distribution specific special cases as far as possible.
- Adapt source url in spec and switch to _service
- Remove patches applied in the new version:
  * 0004-test-Teardown-code-was-never-called.patch
  * 0005-Add-an-explicit-API-entrypoint.patch
  * 0006-openSUSE-Adjust-man-pages-destination.patch
  * 0002-Fix-quiet-option-after-API-patch.patch
* Thu Jun 30 2016 tchvatal@suse.com
- Cleanup slightly with spec-cleaner no factual change
* Thu Dec 25 2014 kgronlund@suse.com
- Add: 0001-Prepend-hostname-on-each-line-when-P-is-set.patch
  - Prepend hostname on each line when -P is set (fate#318220)
- Add: 0002-Fix-quiet-option-after-API-patch.patch
  - Fix quiet option after API patch
* Wed Jan 15 2014 kgronlund@suse.com
- Clarify error message when API calls fail
- Detect use of absolute path when slurping
* Thu Jan  9 2014 kgronlund@suse.com
- Changed to .xz compression
- Updated to latest upstream (cs: b6c8d715)
- added support for multiple source paths in prsync (issue #64)
- made a relative import explicit (issue #66)
- Add support for select.poll on systems where it is available (issue #72)
- Remove restriction on remote relative paths (Issue #83)
- Added programmatic API (with tests)
- Fixed teardown handling for tests
  Cleaned up and added patches:
- Rename pssh-remove_shebangs.patch:
  to 0001-Remove-shebangs-from-library-files.patch
  Also updated patch format
- Rename pssh-man_dir.patch:
  to 0006-openSUSE-Adjust-man-pages-destination.patch
  Also updated patch format
- Rename pssh-quiet.patch: to 0002-Add-quiet-option.patch
- Rename pssh_pcmk_nodes.patch:
  to 0008-openSUSE-add-C-pcmk_nodes-option-to-get-list-of-node.patch
- Rename pssh_askpass_dir.patch:
  to 0007-openSUSE-Add-openSUSE-specific-pssh-askpass-location.patch
- Rename pssh_status_order.patch:
  to 0003-Fix-order-of-command-statuses-returned-by-the-Manage.patch
- Add 0005-Add-an-explicit-API-entrypoint.patch:
  Add an explicit API entry point
- Add 0004-test-Teardown-code-was-never-called.patch:
  Fixes test cases so teardown code is called
* Fri Sep 13 2013 dmuhamedagic@suse.com
- Update pssh_pcmk_nodes.patch: Update interface to crm_node (its
  output changed)
* Wed Sep 11 2013 dmuhamedagic@suse.com
- Add pssh_status_order.patch: Return statuses of ssh commands in
  the proper order (helps in crmsh resource testing and history)
  (bnc#828897)
* Tue Mar 13 2012 tabraham@novell.com
- Update to 2.3.1
  * fixed a problem where man pages were omitted from the tar file
- Changes from 2.3
  * added a --inline-stdout option (issue #57).  Thanks to
    pablo.barbachano for the patch.
  * Added a PSSH_HOST environment variable (issue #62).
  * Added a --version option (issues #33 and #45)
  * Expanded the pssh man page and added man pages for all other
    commands (issues #10 and #55).
  * Fixed askpass on Mac OS X 10.6.7 (issue #50)
  * Many other small fixes
* Tue Feb 14 2012 tserong@suse.com
- exit gracefully when pacemaker is not running (--pcmk_nodes)
- update --quiet option to suppress all status output
- add /usr/bin to the search path for pssh-askpass
- add -C (--pcmk_nodes) option (get host names from cluster: crm_node -l)
- add -q (--quiet) option (suppresses status output)
* Mon Jan  9 2012 tserong@suse.com
- Update license string in spec file
* Thu Apr 28 2011 dmuhamedagic@novell.com
- add man page pssh(1)
- update to v2.2.2
* Sat Mar  6 2010 pascal.bleser@opensuse.org
- initial build (2.1.1)
